# django-plist #

django-plist is a Django application that trivializes the serialization of
Django model objects into the XML format used by Property List files on the
Cocoa platform (iPhone/Mac OS X).

## Installing django-plist ##

Please refer to [`INSTALL.markdown`][install] for installation instructions.
Notice the last section on configuring Django and ensure that you have the
correct settings in `INSTALLED_APPS` and `TEMPLATE_LOADER`.

  [install]: http://github.com/steingrd/django-plist/blob/master/INSTALL.markdown

## Using django-plist ##

Usage instructions can be found in [`docs/overview.markdown`][overview] which
is also available online.

  [overview]: http://github.com/steingrd/django-plist/blob/master/docs/overview.markdown


	
